==============
Usage examples
==============

Usage
-----

Import nanolog and log everything like this::

    from nanolog.utils import nanolog
    nanolog(user, 'access', 'product', product_instance)

ToDO: add more examples here... see also tests.py